==> dasu_3.02.jar: edu/northwestern/dasu/measurement/TraceEntry.java <==
/**
 * Dasu Project
 *
 * File:         TraceEntry.java
 * RCS:          $Id: TraceEntry.java,v 1.0 Mar 25, 2011 11:47:58 AM mas939 Exp $
 * Description:  TraceEntry class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Mar 25, 2011 at 11:47:58 AM
 * Language:     Java
 * Package:      edu.northwestern.dasu.measurement
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2011, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

package edu.northwestern.dasu.measurement;

import java.io.Serializable;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The TraceEntry class ...
 */
public class TraceEntry implements Serializable {
	
	private static final long serialVersionUID = -560510359214066760L;
	
	public Float rtt[] = new Float[]{-1f,-1f,-1f};
	public String router[] = new String[3];
	public Integer numRouters = 0;
}

==> dasu_5.31.jar: edu/northwestern/dasu/measurement/TraceEntry.java <==
/**
 * Dasu Project
 *
 * File:         TraceEntry.java
 * RCS:          $Id: TraceEntry.java,v 1.0 Mar 25, 2011 11:47:58 AM mas939 Exp $
 * Description:  TraceEntry class (see below)
 * Author:       Mario Sanchez
 *               Northwestern Systems Research Group
 *               Department of Computer Science
 *               Northwestern University
 * Created:      Mar 25, 2011 at 11:47:58 AM
 * Language:     Java
 * Package:      edu.northwestern.dasu.measurement
 * Status:       Experimental (Do Not Distribute)
 *
 * (C) Copyright 2011, Northwestern University, all rights reserved.
 *
 * This program is free software; you can redistribute it and/or
 * modify it under the terms of the GNU General Public License
 * as published by the Free Software Foundation; either version 2
 * of the License, or (at your option) any later version.
 * 
 * This program is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 * 
 * You should have received a copy of the GNU General Public License
 * along with this program; if not, write to the Free Software
 * Foundation, Inc., 51 Franklin Street, Fifth Floor, Boston, MA  02110-1301, USA
 */

package edu.northwestern.dasu.measurement;

import java.io.Serializable;
import java.util.Arrays;

import edu.northwestern.cs.aqualab.cattle.jsonsimple.JSONObject;
import edu.northwestern.dasu.util.Jsonizable;

/**
 * @author Mario Sanchez &lt;msanchez@eecs.northwestern.edu&gt;
 *
 * The TraceEntry class ...
 */
public class TraceEntry extends Jsonizable implements Serializable {
	
	private static final long serialVersionUID = 3L;
	
	public Float rtt[] = new Float[]{-1f,-1f,-1f};
	public String router[] = new String[3];
	public Integer numRouters = 0;
	
	public Float[] getRtt() {
		return rtt;
	}
	
	public String[] getRouter() {
		return router;
	}
	
	public Integer getNumRouters() {
		return numRouters;
	}
	
	public JSONObject toJSON() {

		JSONObject json = new JSONObject();
		json.put("router", Arrays.asList(router));
		json.put("rtt", Arrays.asList(rtt));
		return json;
	}

	public String toString() {
		return toJSON().toJSONString();
	}
}
